import type { WebSiteManagementClient, WebSiteManagementModels as Models } from '@azure/arm-appservice';
import type { ServiceClient } from '@azure/ms-rest-js';
import { IActionContext, ISubscriptionContext } from 'vscode-azureextensionui';
import { AppSettingsClientProvider, IAppSettingsClient } from './IAppSettingsClient';
export declare class ParsedSite implements AppSettingsClientProvider {
    readonly id: string;
    readonly isSlot: boolean;
    /**
     * The main site name (does not include the slot name)
     */
    readonly siteName: string;
    readonly slotName?: string;
    /**
     * Combination of the site name and slot name (if applicable), separated by a hyphen
     */
    readonly fullName: string;
    readonly resourceGroup: string;
    readonly location: string;
    readonly serverFarmId: string;
    readonly kind: string;
    readonly initialState?: string;
    readonly isFunctionApp: boolean;
    readonly isWorkflowApp: boolean;
    readonly isKubernetesApp: boolean;
    readonly isLinux: boolean;
    readonly planResourceGroup: string;
    readonly planName: string;
    readonly defaultHostName: string;
    readonly defaultHostUrl: string;
    readonly kuduHostName: string | undefined;
    readonly kuduUrl: string | undefined;
    readonly gitUrl: string | undefined;
    readonly subscription: ISubscriptionContext;
    readonly rawSite: Models.Site;
    constructor(site: Models.Site, subscription: ISubscriptionContext);
    createClient(context: IActionContext & {
        _parsedSiteClients?: {
            [id: string]: SiteClient | undefined;
        };
    }): Promise<SiteClient>;
}
/**
 * Wrapper of a WebSiteManagementClient for use with a specific Site
 * Reduces the number of arguments needed for every call and automatically ensures the 'slot' method is called when appropriate
 */
export declare class SiteClient implements IAppSettingsClient {
    private _client;
    private _genericClient;
    private _site;
    private _cachedSku;
    constructor(internalClient: WebSiteManagementClient, internalGenericClient: ServiceClient, site: ParsedSite);
    get fullName(): string;
    get isLinux(): boolean;
    getIsConsumption(context: IActionContext): Promise<boolean>;
    stop(): Promise<void>;
    start(): Promise<void>;
    getSite(): Promise<Models.Site | undefined>;
    getState(): Promise<string | undefined>;
    getWebAppPublishCredential(): Promise<Models.User>;
    getSiteConfig(): Promise<Models.SiteConfigResource>;
    updateConfiguration(config: Models.SiteConfigResource): Promise<Models.SiteConfigResource>;
    getLogsConfig(): Promise<Models.SiteLogsConfig>;
    updateLogsConfig(config: Models.SiteLogsConfig): Promise<Models.SiteLogsConfig>;
    getAppServicePlan(): Promise<Models.AppServicePlan | undefined>;
    getSourceControl(): Promise<Models.SiteSourceControl>;
    updateSourceControl(siteSourceControl: Models.SiteSourceControl): Promise<Models.SiteSourceControl>;
    syncRepository(): Promise<void>;
    listApplicationSettings(): Promise<Models.StringDictionary>;
    updateApplicationSettings(appSettings: Models.StringDictionary): Promise<Models.StringDictionary>;
    listSlotConfigurationNames(): Promise<Models.SlotConfigNamesResource>;
    updateSlotConfigurationNames(appSettings: Models.SlotConfigNamesResource): Promise<Models.SlotConfigNamesResource>;
    deleteMethod(options?: {
        deleteMetrics?: boolean;
        deleteEmptyServerFarm?: boolean;
        skipDnsRegistration?: boolean;
        customHeaders?: {
            [headerName: string]: string;
        };
    }): Promise<void>;
    listInstanceIdentifiers(): Promise<Models.WebAppInstanceCollection>;
    listSourceControls(): Promise<Models.SourceControlCollection>;
    listFunctions(): Promise<Models.FunctionEnvelopeCollection>;
    listFunctionsNext(nextPageLink: string): Promise<Models.FunctionEnvelopeCollection>;
    getFunction(functionName: string): Promise<Models.FunctionEnvelope>;
    deleteFunction(functionName: string): Promise<void>;
    listFunctionSecrets(functionName: string): Promise<Models.FunctionSecrets>;
    syncFunctionTriggers(): Promise<void>;
    getPublishingUser(): Promise<Models.User>;
    listWebJobs(): Promise<Models.WebJobCollection>;
    listHostKeys(): Promise<Models.HostKeys>;
    listFunctionKeys(functionName: string): Promise<IFunctionKeys>;
    /**
     * Temporary workaround because the azure sdk doesn't return the full site object from Azure
     * Hopefully this can be removed when we move to the new sdk
     * Also, we're caching the sku - for better performance and because it's unlikely to change
     */
    private getCachedSku;
}
/**
 * The type in the sdk doesn't seem to be accurate
 */
export interface IFunctionKeys extends Models.WebAppsListFunctionKeysResponse {
    default?: string;
}
