"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AppInsightsNameStep = void 0;
const vscode_azureextensionui_1 = require("vscode-azureextensionui");
const localize_1 = require("../localize");
const AppInsightsListStep_1 = require("./AppInsightsListStep");
class AppInsightsNameStep extends vscode_azureextensionui_1.AzureWizardPromptStep {
    isNameAvailable(context, name) {
        return __awaiter(this, void 0, void 0, function* () {
            const appInsightsComponents = yield AppInsightsListStep_1.AppInsightsListStep.getAppInsightsComponents(context);
            return !appInsightsComponents.some((ai) => ai.name !== undefined && ai.name.toLowerCase() === name.toLowerCase());
        });
    }
    prompt(context) {
        return __awaiter(this, void 0, void 0, function* () {
            const suggestedName = context.relatedNameTask ? yield context.relatedNameTask : undefined;
            context.newAppInsightsName = (yield context.ui.showInputBox({
                value: suggestedName,
                prompt: 'Enter the name of the new Application Insights resource.',
                validateInput: (value) => __awaiter(this, void 0, void 0, function* () { return yield this.validateApplicationInsightName(context, value); })
            })).trim();
            context.valuesToMask.push(context.newAppInsightsName);
        });
    }
    shouldPrompt(context) {
        return !context.newAppInsightsName;
    }
    validateApplicationInsightName(context, name) {
        return __awaiter(this, void 0, void 0, function* () {
            name = name.trim();
            if (name.length < AppInsightsListStep_1.appInsightsNamingRules.minLength || name.length > AppInsightsListStep_1.appInsightsNamingRules.maxLength) {
                return localize_1.localize('invalidLength', 'The name must be between {0} and {1} characters.', AppInsightsListStep_1.appInsightsNamingRules.minLength, AppInsightsListStep_1.appInsightsNamingRules.maxLength);
            }
            else if (AppInsightsListStep_1.appInsightsNamingRules.invalidCharsRegExp.test(name)) {
                return localize_1.localize('invalidChars', "The name can only contain alphanumeric characters or the symbols ._-()");
            }
            else if (name.endsWith('.')) {
                return localize_1.localize('invalidEndingChar', "The name cannot end in a period.");
            }
            else if (!(yield this.isNameAvailable(context, name))) {
                return localize_1.localize('nameAlreadyExists', 'Application Insights resource "{0}" already exists in subscription "{1}".', name, context.subscriptionDisplayName);
            }
            else {
                return undefined;
            }
        });
    }
}
exports.AppInsightsNameStep = AppInsightsNameStep;
//# sourceMappingURL=AppInsightsNameStep.js.map