"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AppServicePlanSkuStep = void 0;
const vscode_azureextensionui_1 = require("vscode-azureextensionui");
const localize_1 = require("../localize");
const nonNull_1 = require("../utils/nonNull");
const openUrl_1 = require("../utils/openUrl");
const AppKind_1 = require("./AppKind");
const setLocationsTask_1 = require("./setLocationsTask");
class AppServicePlanSkuStep extends vscode_azureextensionui_1.AzureWizardPromptStep {
    prompt(context) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            let skus = context.advancedCreation ? this.getRecommendedSkus().concat(this.getAdvancedSkus()) : this.getRecommendedSkus();
            if (context.newSiteKind === AppKind_1.AppKind.functionapp) {
                skus.push(...this.getElasticPremiumSkus());
            }
            else if ((_a = context.newSiteKind) === null || _a === void 0 ? void 0 : _a.includes(AppKind_1.AppKind.workflowapp)) {
                skus = this.getWorkflowStandardSkus();
            }
            const regExp = context.planSkuFamilyFilter;
            if (regExp) {
                skus = skus.filter(s => !s.family || regExp.test(s.family));
            }
            const pricingTiers = skus.map(s => {
                return {
                    label: s.label || nonNull_1.nonNullProp(s, 'name'),
                    description: s.description || s.tier,
                    data: s,
                    group: s.group || localize_1.localize('additionalOptionsLabel', 'Additional Options')
                };
            });
            pricingTiers.push({ label: localize_1.localize('ShowPricingCalculator', '$(link-external) Show pricing information...'), data: undefined, suppressPersistence: true });
            while (!context.newPlanSku) {
                const placeHolder = localize_1.localize('pricingTierPlaceholder', 'Select a pricing tier');
                context.newPlanSku = (yield context.ui.showQuickPick(pricingTiers, { placeHolder, suppressPersistence: true, enableGrouping: context.advancedCreation })).data;
                if (!context.newPlanSku) {
                    if (context.newSiteOS === AppKind_1.WebsiteOS.linux) {
                        yield openUrl_1.openUrl('https://aka.ms/AA60znj');
                    }
                    else {
                        yield openUrl_1.openUrl('https://aka.ms/AA6202c');
                    }
                }
            }
            yield setLocationsTask_1.setLocationsTask(context);
        });
    }
    shouldPrompt(context) {
        return !context.newPlanSku;
    }
    getRecommendedSkus() {
        const recommendedGroup = localize_1.localize('recommendedGroup', 'Recommended');
        return [
            {
                name: 'F1',
                tier: 'Free',
                size: 'F1',
                family: 'F',
                capacity: 1,
                label: localize_1.localize('freeLabel', 'Free (F1)'),
                description: localize_1.localize('freeDescription', 'Try out Azure at no cost'),
                group: recommendedGroup
            },
            {
                name: 'B1',
                tier: 'Basic',
                size: 'B1',
                family: 'B',
                capacity: 1,
                label: localize_1.localize('basicLabel', 'Basic (B1)'),
                description: localize_1.localize('basicDescription', 'Develop and test'),
                group: recommendedGroup
            },
            {
                name: 'P1v2',
                tier: 'Premium V2',
                size: 'P1v2',
                family: 'Pv2',
                capacity: 1,
                label: localize_1.localize('premiumLabel', 'Premium (P1v2)'),
                description: localize_1.localize('premiumDescription', 'Use in production'),
                group: recommendedGroup
            }
        ];
    }
    getAdvancedSkus() {
        return [
            {
                name: 'B2',
                tier: 'Basic',
                size: 'B2',
                family: 'B',
                capacity: 1
            },
            {
                name: 'B3',
                tier: 'Basic',
                size: 'B3',
                family: 'B',
                capacity: 1
            },
            {
                name: 'S1',
                tier: 'Standard',
                size: 'S1',
                family: 'S',
                capacity: 1
            },
            {
                name: 'S2',
                tier: 'Standard',
                size: 'S2',
                family: 'S',
                capacity: 1
            },
            {
                name: 'S3',
                tier: 'Standard',
                size: 'S3',
                family: 'S',
                capacity: 1
            },
            {
                name: 'P2v2',
                tier: 'Premium V2',
                size: 'P2v2',
                family: 'Pv2',
                capacity: 1
            },
            {
                name: 'P3v2',
                tier: 'Premium V2',
                size: 'P3v2',
                family: 'Pv2',
                capacity: 1
            }
        ];
    }
    getElasticPremiumSkus() {
        return [
            {
                name: 'EP1',
                tier: 'Elastic Premium',
                size: 'EP1',
                family: 'EP',
                capacity: 1
            },
            {
                name: 'EP2',
                tier: 'Elastic Premium',
                size: 'EP2',
                family: 'EP',
                capacity: 1
            },
            {
                name: 'EP3',
                tier: 'Elastic Premium',
                size: 'EP3',
                family: 'EP',
                capacity: 1
            }
        ];
    }
    getWorkflowStandardSkus() {
        return [
            {
                name: 'WS1',
                tier: 'Workflow Standard',
                size: 'WS1',
                family: 'WS',
                capacity: 1
            },
            {
                name: 'WS2',
                tier: 'Workflow Standard',
                size: 'WS2',
                family: 'WS',
                capacity: 1
            },
            {
                name: 'WS3',
                tier: 'Workflow Standard',
                size: 'WS3',
                family: 'WS',
                capacity: 1
            }
        ];
    }
}
exports.AppServicePlanSkuStep = AppServicePlanSkuStep;
//# sourceMappingURL=AppServicePlanSkuStep.js.map