"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CustomLocationListStep = void 0;
const vscode_azureextensionui_1 = require("vscode-azureextensionui");
const localize_1 = require("../localize");
const azureClients_1 = require("../utils/azureClients");
class CustomLocationListStep extends vscode_azureextensionui_1.LocationListStep {
    prompt(context) {
        return __awaiter(this, void 0, void 0, function* () {
            const options = { placeHolder: localize_1.localize('selectLocation', 'Select a location for new resources.'), enableGrouping: true };
            const result = (yield context.ui.showQuickPick(this.getCustomQuickPicks(context), options)).data;
            if ('kubeEnvironment' in result) {
                context.telemetry.properties.pickedCustomLoc = 'true';
                context.customLocation = result;
                // For any resources other than the app, we still need a non-custom location, so we'll use the kubeEnvironment's location
                yield vscode_azureextensionui_1.LocationListStep.setLocation(context, result.kubeEnvironment.location);
                // Plan has very little effect when a custom location is used, so default this info instead of prompting
                context.newPlanName = yield context.relatedNameTask;
                context.newPlanSku = { name: 'K1', tier: 'Kubernetes', size: 'K1', family: 'K', capacity: 1 };
                context.useConsumptionPlan = false;
            }
            else {
                context.telemetry.properties.pickedCustomLoc = 'false';
                yield vscode_azureextensionui_1.LocationListStep.setLocation(context, result.name);
            }
        });
    }
    getCustomQuickPicks(context) {
        const _super = Object.create(null, {
            getQuickPicks: { get: () => super.getQuickPicks }
        });
        return __awaiter(this, void 0, void 0, function* () {
            const picks = yield _super.getQuickPicks.call(this, context);
            if (context.newSiteOS !== 'windows') {
                try {
                    const client = yield azureClients_1.createResourceGraphClient(context);
                    const response = yield client.resources({
                        query: customLocationQuery,
                        subscriptions: [context.subscriptionId]
                    });
                    let customLocations = response.data;
                    customLocations = customLocations.sort((a, b) => a.name.localeCompare(b.name));
                    context.telemetry.properties.hasCustomLoc = String(customLocations.length > 0);
                    picks.unshift(...customLocations.map(cl => {
                        return {
                            label: cl.name,
                            group: localize_1.localize('custom', 'Custom'),
                            data: cl
                        };
                    }));
                }
                catch (error) {
                    context.telemetry.properties.customLocationError = vscode_azureextensionui_1.parseError(error).message;
                    // ignore error and display non-custom locations
                }
            }
            return picks;
        });
    }
}
exports.CustomLocationListStep = CustomLocationListStep;
const customLocationQuery = `
Resources
| where type contains 'Microsoft.Web/kubeEnvironments'
| project kubeEnvironment=pack('id', id, 'name', name, 'location', location, 'properties', properties, 'extendedLocation', extendedLocation), customLocationId=tolower(tostring(extendedLocation.name))
| where isnotnull(customLocationId)
| join (Resources
    | where type contains 'Microsoft.ExtendedLocation/customLocations'
    | project name, customLocationId=tolower(tostring(id)), id) on customLocationId
| project kubeEnvironment, name, id
`;
//# sourceMappingURL=CustomLocationListStep.js.map