"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getWebLocations = exports.setLocationsTask = void 0;
const vscode_azureextensionui_1 = require("vscode-azureextensionui");
const constants_1 = require("../constants");
const azureClients_1 = require("../utils/azureClients");
const nonNull_1 = require("../utils/nonNull");
const AppKind_1 = require("./AppKind");
/**
 * Overwrite the generic 'locationsTask' with a list of locations specific to provider "Microsoft.Web", based on OS and sku
 */
function setLocationsTask(context) {
    return __awaiter(this, void 0, void 0, function* () {
        vscode_azureextensionui_1.LocationListStep.setLocationSubset(context, getWebLocations(context), constants_1.webProvider);
    });
}
exports.setLocationsTask = setLocationsTask;
function getWebLocations(context) {
    return __awaiter(this, void 0, void 0, function* () {
        let options = {};
        if (context.newSiteOS === AppKind_1.WebsiteOS.linux) {
            if (context.newSiteKind === AppKind_1.AppKind.functionapp && context.useConsumptionPlan) {
                options = { linuxDynamicWorkersEnabled: true };
            }
            else {
                options = { linuxWorkersEnabled: true };
            }
        }
        if (context.newPlanSku && context.newPlanSku.tier) {
            options.sku = context.newPlanSku.tier.replace(/\s/g, '');
        }
        const client = yield azureClients_1.createWebSiteClient(context);
        const locations = yield client.listGeoRegions(options);
        return locations.map(l => nonNull_1.nonNullProp(l, 'name'));
    });
}
exports.getWebLocations = getWebLocations;
//# sourceMappingURL=setLocationsTask.js.map