"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.deleteSite = void 0;
const util_1 = require("util");
const vscode = require("vscode");
const vscode_azureextensionui_1 = require("vscode-azureextensionui");
const extensionVariables_1 = require("./extensionVariables");
const localize_1 = require("./localize");
function deleteSite(context, site) {
    return __awaiter(this, void 0, void 0, function* () {
        const confirmMessage = site.isSlot ?
            localize_1.localize('confirmDeleteSlot', 'Are you sure you want to delete slot "{0}"?', site.fullName) :
            site.isFunctionApp ?
                localize_1.localize('confirmDeleteFunctionApp', 'Are you sure you want to delete function app "{0}"?', site.fullName) :
                localize_1.localize('confirmDeleteWebApp', 'Are you sure you want to delete web app "{0}"?', site.fullName);
        yield context.ui.showWarningMessage(confirmMessage, { modal: true, stepName: 'confirmDelete' }, vscode_azureextensionui_1.DialogResponses.deleteResponse);
        let plan;
        let deletePlan = false;
        const client = yield site.createClient(context);
        if (!site.isSlot) {
            // API calls not necessary for deployment slots
            plan = yield client.getAppServicePlan();
        }
        if (!site.isSlot && plan && !util_1.isNullOrUndefined(plan.numberOfSites) && plan.numberOfSites < 2) {
            const message = localize_1.localize('deleteLastServicePlan', 'This is the last app in the App Service plan "{0}". Do you want to delete this App Service plan to prevent unexpected charges?', plan.name);
            const input = yield context.ui.showWarningMessage(message, { modal: true, stepName: 'lastAppOnPlan' }, vscode_azureextensionui_1.DialogResponses.yes, vscode_azureextensionui_1.DialogResponses.no);
            deletePlan = input === vscode_azureextensionui_1.DialogResponses.yes;
        }
        const deleting = site.isSlot ?
            localize_1.localize('DeletingSlot', 'Deleting slot "{0}"...', site.fullName) :
            site.isFunctionApp ?
                localize_1.localize('DeletingFunctionApp', 'Deleting function app "{0}"...', site.fullName) :
                localize_1.localize('DeletingWebApp', 'Deleting web app "{0}"...', site.fullName);
        const deleteSucceeded = site.isSlot ?
            localize_1.localize('deletedSlot', 'Successfully deleted slot "{0}".', site.fullName) :
            site.isFunctionApp ?
                localize_1.localize('deletedFunctionApp', 'Successfully deleted function app "{0}".', site.fullName) :
                localize_1.localize('deletedWebApp', 'Successfully deleted web app "{0}".', site.fullName);
        yield vscode.window.withProgress({ location: vscode.ProgressLocation.Notification, title: deleting }, () => __awaiter(this, void 0, void 0, function* () {
            extensionVariables_1.ext.outputChannel.appendLog(deleting);
            yield client.deleteMethod({ deleteEmptyServerFarm: deletePlan });
            void vscode.window.showInformationMessage(deleteSucceeded);
            extensionVariables_1.ext.outputChannel.appendLog(deleteSucceeded);
        }));
    });
}
exports.deleteSite = deleteSite;
//# sourceMappingURL=deleteSite.js.map