"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.deployWar = void 0;
const fs = require("fs");
const createKuduClient_1 = require("../createKuduClient");
const localize_1 = require("../localize");
const pathUtils_1 = require("../utils/pathUtils");
const waitForDeploymentToComplete_1 = require("./waitForDeploymentToComplete");
function deployWar(context, site, fsPath) {
    return __awaiter(this, void 0, void 0, function* () {
        if (pathUtils_1.getFileExtension(fsPath) !== 'war') {
            throw new Error(localize_1.localize('NotAWarError', 'Path specified is not a war file'));
        }
        const kuduClient = yield createKuduClient_1.createKuduClient(context, site);
        yield kuduClient.pushDeployment.warPushDeploy(() => fs.createReadStream(fsPath), { isAsync: true });
        yield waitForDeploymentToComplete_1.waitForDeploymentToComplete(context, site);
    });
}
exports.deployWar = deployWar;
//# sourceMappingURL=deployWar.js.map