"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.deployZip = void 0;
const createKuduClient_1 = require("../createKuduClient");
const delayFirstWebAppDeploy_1 = require("./delayFirstWebAppDeploy");
const runWithZipStream_1 = require("./runWithZipStream");
const waitForDeploymentToComplete_1 = require("./waitForDeploymentToComplete");
function deployZip(context, site, fsPath, aspPromise, pathFileMap) {
    return __awaiter(this, void 0, void 0, function* () {
        const kuduClient = yield createKuduClient_1.createKuduClient(context, site);
        yield runWithZipStream_1.runWithZipStream(context, {
            fsPath, site, pathFileMap,
            callback: (zipStream) => __awaiter(this, void 0, void 0, function* () {
                yield kuduClient.pushDeployment.zipPushDeploy(() => zipStream, { isAsync: true, author: 'VS Code' });
            })
        });
        yield waitForDeploymentToComplete_1.waitForDeploymentToComplete(context, site);
        // https://github.com/Microsoft/vscode-azureappservice/issues/644
        // This delay is a temporary stopgap that should be resolved with the new pipelines
        yield delayFirstWebAppDeploy_1.delayFirstWebAppDeploy(context, site, aspPromise);
    });
}
exports.deployZip = deployZip;
//# sourceMappingURL=deployZip.js.map