"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.showDeployConfirmation = void 0;
const path_1 = require("path");
const vscode_1 = require("vscode");
const vscode_azureextensionui_1 = require("vscode-azureextensionui");
const extensionVariables_1 = require("../extensionVariables");
const localize_1 = require("../localize");
const delay_1 = require("../utils/delay");
const settings_1 = require("../utils/settings");
const IDeployContext_1 = require("./IDeployContext");
function showDeployConfirmation(context, site, deployCommandId) {
    return __awaiter(this, void 0, void 0, function* () {
        const warning = localize_1.localize('confirmDeploy', 'Are you sure you want to deploy to "{0}"? This will overwrite any previous deployment and cannot be undone.', site.fullName);
        const items = [{ title: localize_1.localize('deploy', 'Deploy') }];
        const resetDefault = { title: 'Reset default' };
        if (context.appSource === IDeployContext_1.AppSource.setting) {
            items.push(resetDefault);
        }
        const result = yield context.ui.showWarningMessage(warning, { modal: true, stepName: 'confirmDestructiveDeployment' }, ...items);
        // a temporary workaround for this issue:
        // https://github.com/Microsoft/vscode-azureappservice/issues/844
        yield delay_1.delay(500);
        if (result === resetDefault) {
            const settingsPath = path_1.join(context.workspaceFolder.uri.fsPath, '.vscode', 'settings.json');
            yield settings_1.updateWorkspaceSetting(context.defaultAppSetting, '', context.workspaceFolder.uri.fsPath, extensionVariables_1.ext.prefix);
            yield vscode_1.window.showTextDocument(vscode_1.Uri.file(settingsPath));
            // If resetDefault button was clicked we ask what and where to deploy again
            // don't wait
            void vscode_1.commands.executeCommand(deployCommandId);
            throw new vscode_azureextensionui_1.UserCancelledError('resetDefault');
        }
    });
}
exports.showDeployConfirmation = showDeployConfirmation;
//# sourceMappingURL=showDeployConfirmation.js.map