"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.syncTriggersPostDeploy = void 0;
const retry = require("p-retry");
const extensionVariables_1 = require("../extensionVariables");
const localize_1 = require("../localize");
const delay_1 = require("../utils/delay");
function syncTriggersPostDeploy(context, site) {
    return __awaiter(this, void 0, void 0, function* () {
        // Per functions team a short delay is necessary before syncing triggers for two reasons:
        // (1) The call will definitely fail. (2) It will spin up a container unnecessarily in some cases.
        // Chose 10 because deploy logs say "App container will begin restart within 10 seconds."
        yield delay_1.delay(10 * 1000);
        // This can often fail with error "ServiceUnavailable", so we will retry with exponential backoff
        // Retry at most 5 times, with initial spacing of 5 seconds and total max time of about 3 minutes
        const retries = 5;
        const client = yield site.createClient(context);
        yield retry((currentAttempt) => __awaiter(this, void 0, void 0, function* () {
            const message = currentAttempt === 1 ?
                localize_1.localize('syncingTriggers', 'Syncing triggers...') :
                localize_1.localize('syncingTriggersAttempt', 'Syncing triggers (Attempt {0}/{1})...', currentAttempt, retries + 1);
            extensionVariables_1.ext.outputChannel.appendLog(message, { resourceName: site.fullName });
            yield client.syncFunctionTriggers();
        }), { retries, minTimeout: 5 * 1000 });
    });
}
exports.syncTriggersPostDeploy = syncTriggersPostDeploy;
//# sourceMappingURL=syncTriggersPostDeploy.js.map