"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GitHubBranchListStep = void 0;
const vscode_azureextensionui_1 = require("vscode-azureextensionui");
const localize_1 = require("../localize");
const nonNull_1 = require("../utils/nonNull");
const connectToGitHub_1 = require("./connectToGitHub");
class GitHubBranchListStep extends vscode_azureextensionui_1.AzureWizardPromptStep {
    prompt(context) {
        return __awaiter(this, void 0, void 0, function* () {
            const placeHolder = localize_1.localize('chooseBranch', 'Choose branch');
            let branchData;
            const picksCache = { picks: [] };
            let url = `${nonNull_1.nonNullProp(context, 'repoData').url}/branches`;
            // eslint-disable-next-line no-constant-condition
            while (true) {
                branchData = (yield context.ui.showQuickPick(this.getBranchPicks(context, picksCache, url), { placeHolder })).data;
                if (typeof branchData === 'string') {
                    url = branchData;
                }
                else {
                    break;
                }
            }
            context.branchData = branchData;
        });
    }
    shouldPrompt(context) {
        return !context.branchData;
    }
    getBranchPicks(context, picksCache, url) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield connectToGitHub_1.getGitHubQuickPicksWithLoadMore(context, picksCache, url, 'name');
        });
    }
}
exports.GitHubBranchListStep = GitHubBranchListStep;
//# sourceMappingURL=GitHubBranchListStep.js.map