"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GitHubOrgListStep = void 0;
const vscode_azureextensionui_1 = require("vscode-azureextensionui");
const localize_1 = require("../localize");
const connectToGitHub_1 = require("./connectToGitHub");
class GitHubOrgListStep extends vscode_azureextensionui_1.AzureWizardPromptStep {
    prompt(context) {
        return __awaiter(this, void 0, void 0, function* () {
            const placeHolder = localize_1.localize('chooseOrg', 'Choose organization.');
            context.orgData = (yield context.ui.showQuickPick(this.getOrganizations(context), { placeHolder })).data;
        });
    }
    shouldPrompt(context) {
        return !context.orgData;
    }
    getOrganizations(context) {
        return __awaiter(this, void 0, void 0, function* () {
            const [userData] = yield connectToGitHub_1.getGitHubJsonResponse(context, 'https://api.github.com/user');
            let quickPickItems = connectToGitHub_1.createQuickPickFromJsons(userData, 'login');
            const [orgData] = yield connectToGitHub_1.getGitHubJsonResponse(context, 'https://api.github.com/user/orgs');
            quickPickItems = quickPickItems.concat(connectToGitHub_1.createQuickPickFromJsons(orgData, 'login'));
            return quickPickItems;
        });
    }
}
exports.GitHubOrgListStep = GitHubOrgListStep;
//# sourceMappingURL=GitHubOrgListStep.js.map