"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.registerSiteCommand = void 0;
const vscode_azureextensionui_1 = require("vscode-azureextensionui");
const localize_1 = require("./localize");
/**
 * Use this to get extra error handling for commands that interact directly with site APIs.
 */
function registerSiteCommand(commandId, callback, debounce) {
    vscode_azureextensionui_1.registerCommand(commandId, 
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    (context, ...args) => __awaiter(this, void 0, void 0, function* () {
        try {
            // eslint-disable-next-line @typescript-eslint/no-unsafe-return
            return yield Promise.resolve(callback(context, ...args));
        }
        catch (error) {
            handleSiteErrors(context, error);
        }
    }), debounce);
}
exports.registerSiteCommand = registerSiteCommand;
function handleSiteErrors(context, error) {
    const parsedError = vscode_azureextensionui_1.parseError(error);
    if (parsedError.errorType === '502' || parsedError.errorType === '503') {
        context.errorHandling.suppressReportIssue = true;
        const troubleshooting = localize_1.localize('502or503Troubleshooting', 'View troubleshooting tips [here](https://aka.ms/AA772mm).');
        throw new Error(`${parsedError.message} ${troubleshooting}`);
    }
    else {
        throw error;
    }
}
//# sourceMappingURL=registerSiteCommand.js.map