"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.setRemoteDebug = exports.reportMessage = void 0;
const vscode = require("vscode");
const vscode_azureextensionui_1 = require("vscode-azureextensionui");
const extensionVariables_1 = require("../extensionVariables");
const localize_1 = require("../localize");
function reportMessage(message, progress, token) {
    if (token.isCancellationRequested) {
        throw new vscode_azureextensionui_1.UserCancelledError('remoteDebugReportMessage');
    }
    extensionVariables_1.ext.outputChannel.appendLog(message);
    progress.report({ message: message });
}
exports.reportMessage = reportMessage;
function setRemoteDebug(context, isRemoteDebuggingToBeEnabled, confirmMessage, noopMessage, site, siteConfig, progress, token, learnMoreLink) {
    return __awaiter(this, void 0, void 0, function* () {
        const client = yield site.createClient(context);
        const state = yield client.getState();
        if (state && state.toLowerCase() === 'stopped') {
            throw new Error(localize_1.localize('remoteDebugStopped', 'The app must be running, but is currently in state "Stopped". Start the app to continue.'));
        }
        if (isRemoteDebuggingToBeEnabled !== siteConfig.remoteDebuggingEnabled) {
            const confirmButton = isRemoteDebuggingToBeEnabled ? { title: 'Enable' } : { title: 'Disable' };
            // don't have to check input as this handles cancels and learnMore responses
            yield context.ui.showWarningMessage(confirmMessage, { modal: true, learnMoreLink }, confirmButton);
            siteConfig.remoteDebuggingEnabled = isRemoteDebuggingToBeEnabled;
            reportMessage(localize_1.localize('remoteDebugUpdate', 'Updating site configuration to set remote debugging...'), progress, token);
            yield vscode_azureextensionui_1.callWithTelemetryAndErrorHandling('appService.remoteDebugUpdateConfiguration', (updateContext) => __awaiter(this, void 0, void 0, function* () {
                updateContext.errorHandling.suppressDisplay = true;
                updateContext.errorHandling.rethrow = true;
                yield client.updateConfiguration(siteConfig);
            }));
            reportMessage(localize_1.localize('remoteDebugUpdateDone', 'Updating site configuration done.'), progress, token);
        }
        else {
            // Update not needed
            if (noopMessage) {
                void vscode.window.showWarningMessage(noopMessage);
            }
        }
    });
}
exports.setRemoteDebug = setRemoteDebug;
//# sourceMappingURL=remoteDebugCommon.js.map