"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.deleteFunctionSlot = exports.getFunctionSlot = exports.listFunctionsSlot = void 0;
/**
 * Temporary workaround because this isn't in azure sdk yet
 */
function listFunctionsSlot(genericClient, id) {
    return __awaiter(this, void 0, void 0, function* () {
        const response = yield genericClient.sendRequest({ method: 'GET', url: getUrlPath(id) });
        const rawResult = response.parsedBody;
        const result = rawResult.value.map(convertRawResource);
        // eslint-disable-next-line @typescript-eslint/no-unsafe-member-access, @typescript-eslint/no-explicit-any
        result.nextLink = convertPropertyValue(rawResult.nextLink);
        return result;
    });
}
exports.listFunctionsSlot = listFunctionsSlot;
/**
 * Temporary workaround because this isn't in azure sdk yet
 */
function getFunctionSlot(genericClient, id, functionName) {
    return __awaiter(this, void 0, void 0, function* () {
        const response = yield genericClient.sendRequest({ method: 'GET', url: getUrlPath(id, functionName) });
        return convertRawResource(response.parsedBody);
    });
}
exports.getFunctionSlot = getFunctionSlot;
/**
 * Temporary workaround because this isn't in azure sdk yet
 */
function deleteFunctionSlot(genericClient, id, functionName) {
    return __awaiter(this, void 0, void 0, function* () {
        yield genericClient.sendRequest({ method: 'DELETE', url: getUrlPath(id, functionName) });
    });
}
exports.deleteFunctionSlot = deleteFunctionSlot;
function getUrlPath(id, functionName) {
    return `${id}/functions${functionName ? '/' + functionName : ''}?api-version=2016-08-01`;
}
/**
 * Mimics what the azure sdk does under the covers to create the returned object
 */
function convertRawResource(resource) {
    const result = {};
    for (const key of Object.keys(resource.properties)) {
        result[convertPropertyName(key)] = convertPropertyValue(resource.properties[key]);
    }
    result.name = resource.name;
    result.id = resource.id;
    result.type = resource.type;
    result.location = resource.location;
    return result;
}
/**
 * Converts property name like "function_app_id" to "functionAppId"
 */
function convertPropertyName(name) {
    // eslint-disable-next-line no-constant-condition
    while (true) {
        const match = /_([a-z])/g.exec(name);
        if (match) {
            name = name.replace(match[0], match[1].toUpperCase());
        }
        else {
            return name;
        }
    }
}
/**
 * The azure sdk types all use undefined instead of null, so ensure we align with that
 */
function convertPropertyValue(value) {
    return value === null ? undefined : value;
}
//# sourceMappingURL=slotFunctionOperations.js.map