"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.swapSlot = void 0;
const vscode_1 = require("vscode");
const extensionVariables_1 = require("./extensionVariables");
const localize_1 = require("./localize");
const azureClients_1 = require("./utils/azureClients");
function swapSlot(context, sourceSlot, existingSlots) {
    return __awaiter(this, void 0, void 0, function* () {
        const productionSlotLabel = 'production';
        const otherSlots = [{
                label: productionSlotLabel,
                data: undefined
            }];
        for (const slot of existingSlots) {
            if (sourceSlot.slotName !== slot.slotName) {
                // Deployment slots must have an unique name
                const otherSlot = {
                    // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
                    label: slot.slotName,
                    data: slot
                };
                otherSlots.push(otherSlot);
            }
        }
        const placeHolder = localize_1.localize('selectSlotToSwap', 'Select which slot to swap with "{0}".', sourceSlot.slotName);
        const targetSlot = (yield context.ui.showQuickPick(otherSlots, { placeHolder, stepName: 'swapSlot' })).data;
        const targetSlotLabel = targetSlot ? targetSlot.fullName : `${sourceSlot.siteName}-${productionSlotLabel}`;
        const swappingSlots = localize_1.localize('swapping', 'Swapping "{0}" with "{1}"...', targetSlotLabel, sourceSlot.fullName);
        const successfullySwapped = localize_1.localize('swapped', 'Successfully swapped "{0}" with "{1}".', targetSlotLabel, sourceSlot.fullName);
        extensionVariables_1.ext.outputChannel.appendLog(swappingSlots);
        const client = yield azureClients_1.createWebSiteClient([context, sourceSlot.subscription]);
        yield vscode_1.window.withProgress({ location: vscode_1.ProgressLocation.Notification, title: swappingSlots }, () => __awaiter(this, void 0, void 0, function* () {
            // if targetSlot was assigned undefined, the user selected 'production'
            if (!targetSlot) {
                // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
                yield client.webApps.swapSlotWithProduction(sourceSlot.resourceGroup, sourceSlot.siteName, { targetSlot: sourceSlot.slotName, preserveVnet: true });
            }
            else {
                // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
                yield client.webApps.swapSlotSlot(sourceSlot.resourceGroup, sourceSlot.siteName, { targetSlot: targetSlot.slotName, preserveVnet: true }, sourceSlot.slotName);
            }
            void vscode_1.window.showInformationMessage(successfullySwapped);
            extensionVariables_1.ext.outputChannel.appendLog(successfullySwapped);
        }));
    });
}
exports.swapSlot = swapSlot;
//# sourceMappingURL=swapSlot.js.map