"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileTreeItem = void 0;
const vscode_1 = require("vscode");
const vscode_azureextensionui_1 = require("vscode-azureextensionui");
const extensionVariables_1 = require("../extensionVariables");
const localize_1 = require("../localize");
const siteFiles_1 = require("../siteFiles");
/**
 * NOTE: This leverages a command with id `ext.prefix + '.openFile'` that should be registered by each extension
 */
class FileTreeItem extends vscode_azureextensionui_1.AzExtTreeItem {
    constructor(parent, site, label, path, isReadOnly) {
        super(parent);
        this.contextValue = FileTreeItem.contextValue;
        this.site = site;
        this.label = label;
        this.path = path;
        this.isReadOnly = isReadOnly;
    }
    get iconPath() {
        return new vscode_1.ThemeIcon('file');
    }
    get commandId() {
        return extensionVariables_1.ext.prefix + '.openFile';
    }
    openReadOnly(context) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.runWithTemporaryDescription(context, localize_1.localize('opening', 'Opening...'), () => __awaiter(this, void 0, void 0, function* () {
                const file = yield siteFiles_1.getFile(context, this.site, this.path);
                yield vscode_azureextensionui_1.openReadOnlyContent(this, file.data, '');
            }));
        });
    }
}
exports.FileTreeItem = FileTreeItem;
FileTreeItem.contextValue = 'file';
//# sourceMappingURL=FileTreeItem.js.map