"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FolderTreeItem = void 0;
const vscode_1 = require("vscode");
const vscode_azureextensionui_1 = require("vscode-azureextensionui");
const localize_1 = require("../localize");
const siteFiles_1 = require("../siteFiles");
const FileTreeItem_1 = require("./FileTreeItem");
class FolderTreeItem extends vscode_azureextensionui_1.AzExtParentTreeItem {
    constructor(parent, site, label, path, isReadOnly) {
        super(parent);
        this.contextValue = FolderTreeItem.contextValue;
        this.childTypeLabel = localize_1.localize('fileOrFolder', 'file or folder');
        this._isRoot = false;
        this.site = site;
        this.label = label;
        this.path = path;
        this.isReadOnly = isReadOnly;
    }
    get iconPath() {
        return new vscode_1.ThemeIcon('folder');
    }
    hasMoreChildrenImpl() {
        return false;
    }
    get description() {
        return this._isRoot && this.isReadOnly ? localize_1.localize('readOnly', 'Read-only') : undefined;
    }
    loadMoreChildrenImpl(_clearCache, context) {
        return __awaiter(this, void 0, void 0, function* () {
            let files = yield siteFiles_1.listFiles(context, this.site, this.path);
            // this file is being accessed by Kudu and is not viewable
            files = files.filter(f => f.mime !== 'text/xml' || !f.name.includes('LogFiles-kudu-trace_pending.xml'));
            return files.map(file => {
                const home = 'home';
                // truncate the home of the path
                // the substring starts at file.path.indexOf(home) because the path sometimes includes site/ or D:\
                // the home.length + 1 is to account for the trailing slash, Linux uses / and Window uses \
                const fsPath = file.path.substring(file.path.indexOf(home) + home.length + 1);
                return file.mime === 'inode/directory' ? new FolderTreeItem(this, this.site, file.name, fsPath, this.isReadOnly) : new FileTreeItem_1.FileTreeItem(this, this.site, file.name, fsPath, this.isReadOnly);
            });
        });
    }
    compareChildrenImpl(ti1, ti2) {
        let result = instanceOfCompare(ti1, ti2, vscode_azureextensionui_1.GenericTreeItem);
        if (result === undefined) {
            result = instanceOfCompare(ti1, ti2, FolderTreeItem);
        }
        return result === undefined ? ti1.label.localeCompare(ti2.label) : result;
    }
}
exports.FolderTreeItem = FolderTreeItem;
FolderTreeItem.contextValue = 'folder';
function instanceOfCompare(ti1, ti2, typeToCompare) {
    if (!(ti1 instanceof typeToCompare) && ti2 instanceof typeToCompare) {
        return 1;
    }
    else if (ti1 instanceof typeToCompare && !(ti2 instanceof typeToCompare)) {
        return -1;
    }
    else {
        return undefined;
    }
}
//# sourceMappingURL=FolderTreeItem.js.map