"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LogFilesTreeItem = void 0;
const vscode_1 = require("vscode");
const vscode_azureextensionui_1 = require("vscode-azureextensionui");
const extensionVariables_1 = require("../extensionVariables");
const localize_1 = require("../localize");
const FolderTreeItem_1 = require("./FolderTreeItem");
/**
 * NOTE: This leverages a command with id `ext.prefix + '.startStreamingLogs'` that should be registered by each extension
 */
class LogFilesTreeItem extends FolderTreeItem_1.FolderTreeItem {
    constructor(parent, site) {
        super(parent, site, localize_1.localize('logFiles', 'Logs'), '/LogFiles', true);
        this.contextValue = LogFilesTreeItem.contextValue;
        this.suppressMaskLabel = true;
        this._isRoot = true;
    }
    loadMoreChildrenImpl(clearCache, context) {
        const _super = Object.create(null, {
            loadMoreChildrenImpl: { get: () => super.loadMoreChildrenImpl }
        });
        return __awaiter(this, void 0, void 0, function* () {
            let children;
            try {
                children = yield _super.loadMoreChildrenImpl.call(this, clearCache, context);
            }
            catch (error) {
                // We want to show the log stream tree item in all cases, so handle errors here
                const message = vscode_azureextensionui_1.parseError(error).message;
                context.telemetry.properties.logFilesError = message;
                children = [new vscode_azureextensionui_1.GenericTreeItem(this, {
                        label: localize_1.localize('errorTreeItem', 'Error: {0}', message),
                        contextValue: 'logFilesError'
                    })];
            }
            if (clearCache) {
                const ti = new vscode_azureextensionui_1.GenericTreeItem(this, {
                    contextValue: 'logStream',
                    commandId: extensionVariables_1.ext.prefix + '.startStreamingLogs',
                    iconPath: new vscode_1.ThemeIcon('play'),
                    label: localize_1.localize('connectLogStream', 'Connect to Log Stream...')
                });
                ti.commandArgs = [this.parent]; // should be the slot tree item
                children.push(ti);
            }
            return children;
        });
    }
}
exports.LogFilesTreeItem = LogFilesTreeItem;
LogFilesTreeItem.contextValue = 'logFiles';
//# sourceMappingURL=LogFilesTreeItem.js.map