"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.tryGetWebAppSlot = exports.tryGetWebApp = exports.tryGetAppServicePlan = void 0;
const vscode_azureextensionui_1 = require("vscode-azureextensionui");
function tryGetAppServicePlan(client, resourceGroupName, name) {
    return __awaiter(this, void 0, void 0, function* () {
        return yield tryGetSiteResource(() => __awaiter(this, void 0, void 0, function* () { return yield client.appServicePlans.get(resourceGroupName, name); }));
    });
}
exports.tryGetAppServicePlan = tryGetAppServicePlan;
function tryGetWebApp(client, resourceGroupName, name) {
    return __awaiter(this, void 0, void 0, function* () {
        return yield tryGetSiteResource(() => __awaiter(this, void 0, void 0, function* () { return yield client.webApps.get(resourceGroupName, name); }));
    });
}
exports.tryGetWebApp = tryGetWebApp;
function tryGetWebAppSlot(client, resourceGroupName, name, slot) {
    return __awaiter(this, void 0, void 0, function* () {
        return yield tryGetSiteResource(() => __awaiter(this, void 0, void 0, function* () { return yield client.webApps.getSlot(resourceGroupName, name, slot); }));
    });
}
exports.tryGetWebAppSlot = tryGetWebAppSlot;
/**
 * Workaround for https://github.com/Azure/azure-sdk-for-js/issues/10457
 * The azure sdk currently returns the error when a resource isn't found. Instead, they should throw the error or return undefined. We will do the latter.
 *
 * Example values for `result`:
 * 1. { "error": { "code": "ResourceGroupNotFound", "message": "Resource group 'appsvc_linux_centralus' could not be found." }}
 * 2. { "error": { "code": "ResourceNotFound", "message": "The Resource 'Microsoft.Web/serverFarms/appsvc_linux_centralus' under resource group 'appsvc_linux_centralus' was not found. For more details please go to https://aka.ms/ARMResourceNotFoundFix" }}
 * 3. { "Code": "NotFound", "Message": "Server farm with name appsvc_linux_centralus not found." }
 */
function tryGetSiteResource(callback) {
    return __awaiter(this, void 0, void 0, function* () {
        const result = yield callback();
        const regExp = /NotFound/i;
        if (regExp.test(vscode_azureextensionui_1.parseError(result).errorType) || ('error' in result && regExp.test(vscode_azureextensionui_1.parseError(result.error).errorType))) {
            return undefined;
        }
        else {
            return result;
        }
    });
}
//# sourceMappingURL=tryGetSiteResource.js.map