"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ignore404Error = exports.retryKuduCall = void 0;
const retry = require("p-retry");
const vscode_azureextensionui_1 = require("vscode-azureextensionui");
/**
 * Kudu calls are not the most reliable - this will retry a few times with exponential backoff. Each "set" of retries will take a max of about 15 seconds
 */
function retryKuduCall(context, methodName, callback) {
    return __awaiter(this, void 0, void 0, function* () {
        return yield retry((attempt) => __awaiter(this, void 0, void 0, function* () {
            if (attempt > 1) { // only add telemetry if it needed a retry
                const existingAttempt = context.telemetry.measurements.kuduMaxRetry;
                if (existingAttempt === undefined || existingAttempt < attempt) {
                    context.telemetry.measurements.kuduMaxRetry = attempt;
                    context.telemetry.properties.kuduRetryMethod = methodName;
                }
            }
            return yield callback();
        }), { retries: 4, minTimeout: 1000 });
    });
}
exports.retryKuduCall = retryKuduCall;
/**
 * 404 is somewhat common when listing deployment logs. This will swallow the error and display the logs we _can_ retrieve
 * https://github.com/microsoft/vscode-azureappservice/issues/1365
 */
function ignore404Error(context, callback) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            yield callback();
        }
        catch (error) {
            if (vscode_azureextensionui_1.parseError(error).errorType === '404') {
                context.telemetry.properties.ignore404Error = 'true';
            }
            else {
                throw error;
            }
        }
    });
}
exports.ignore404Error = ignore404Error;
//# sourceMappingURL=kuduUtils.js.map