"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getWorkspaceSettingFromAnyFolder = exports.getWorkspaceSetting = exports.getGlobalSetting = exports.updateWorkspaceSetting = exports.updateGlobalSetting = void 0;
const vscode_1 = require("vscode");
function updateGlobalSetting(section, value, prefix) {
    return __awaiter(this, void 0, void 0, function* () {
        const projectConfiguration = vscode_1.workspace.getConfiguration(prefix);
        yield projectConfiguration.update(section, value, vscode_1.ConfigurationTarget.Global);
    });
}
exports.updateGlobalSetting = updateGlobalSetting;
function updateWorkspaceSetting(section, value, fsPath, prefix) {
    return __awaiter(this, void 0, void 0, function* () {
        const projectConfiguration = vscode_1.workspace.getConfiguration(prefix, getScope(fsPath));
        yield projectConfiguration.update(section, value);
    });
}
exports.updateWorkspaceSetting = updateWorkspaceSetting;
function getGlobalSetting(key, prefix) {
    const projectConfiguration = vscode_1.workspace.getConfiguration(prefix);
    const result = projectConfiguration.inspect(key);
    return result && result.globalValue;
}
exports.getGlobalSetting = getGlobalSetting;
function getWorkspaceSetting(key, prefix, fsPath) {
    const projectConfiguration = vscode_1.workspace.getConfiguration(prefix, getScope(fsPath));
    return projectConfiguration.get(key);
}
exports.getWorkspaceSetting = getWorkspaceSetting;
function getScope(fsPath) {
    return typeof fsPath === 'string' ? vscode_1.Uri.file(fsPath) : fsPath;
}
function getWorkspaceSettingFromAnyFolder(key, prefix) {
    if (vscode_1.workspace.workspaceFolders && vscode_1.workspace.workspaceFolders.length > 0) {
        let result;
        for (const folder of vscode_1.workspace.workspaceFolders) {
            const projectConfiguration = vscode_1.workspace.getConfiguration(prefix, folder.uri);
            const folderResult = projectConfiguration.get(key);
            if (!result) {
                result = folderResult;
            }
            else if (folderResult && result !== folderResult) {
                return undefined;
            }
        }
        return result;
    }
    else {
        return getGlobalSetting(key, prefix);
    }
}
exports.getWorkspaceSettingFromAnyFolder = getWorkspaceSettingFromAnyFolder;
//# sourceMappingURL=settings.js.map