"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.taskUtils = void 0;
const vscode_1 = require("vscode");
const pathUtils_1 = require("./pathUtils");
var taskUtils;
(function (taskUtils) {
    function getFsPathFromTask(task) {
        var _a;
        if (typeof task.scope === 'object') {
            const workspaceFolder = task.scope;
            return (_a = workspaceFolder.uri) === null || _a === void 0 ? void 0 : _a.fsPath;
        }
        else {
            return undefined;
        }
    }
    taskUtils.getFsPathFromTask = getFsPathFromTask;
    /**
     * Returns true if the task's scope is a workspace folder matching the given path or if the task is not associated with a path
     */
    function isTaskInScopeOfPath(task, fsPath) {
        if (task.scope === vscode_1.TaskScope.Global || task.scope === vscode_1.TaskScope.Workspace) {
            return true;
        }
        else {
            const taskPath = getFsPathFromTask(task);
            return !!taskPath && (pathUtils_1.isPathEqual(taskPath, fsPath) || pathUtils_1.isSubpath(taskPath, fsPath));
        }
    }
    taskUtils.isTaskInScopeOfPath = isTaskInScopeOfPath;
    function isTaskScopeEqual(task1, task2) {
        if (task1.scope === task2.scope) { // handles the case where the scopes are not associated with a path
            return true;
        }
        else {
            const task1Path = getFsPathFromTask(task1);
            const task2Path = getFsPathFromTask(task2);
            return !!task1Path && !!task2Path && pathUtils_1.isPathEqual(task1Path, task2Path);
        }
    }
    taskUtils.isTaskScopeEqual = isTaskScopeEqual;
    function isTaskEqual(task1, task2) {
        return isTaskScopeEqual(task1, task2) && task1.name === task2.name && task1.source === task2.source && task1.definition.type === task2.definition.type;
    }
    taskUtils.isTaskEqual = isTaskEqual;
    function findTask(deployFsPath, taskName, tasks) {
        return __awaiter(this, void 0, void 0, function* () {
            tasks = tasks || (yield vscode_1.tasks.fetchTasks());
            taskName = taskName.toLowerCase();
            return tasks.find(t => {
                return isTaskInScopeOfPath(t, deployFsPath) && (taskName === t.name.toLowerCase() ||
                    taskName === `${t.definition.type}: ` + t.name.toLowerCase() ||
                    taskName === `${t.source}: ` + t.name.toLowerCase());
            });
        });
    }
    taskUtils.findTask = findTask;
    /**
     * Handles condition where we don't need to start the task because it's already running
     */
    function executeIfNotActive(task) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!vscode_1.tasks.taskExecutions.find(t => isTaskEqual(t.task, task))) {
                yield vscode_1.tasks.executeTask(task);
            }
        });
    }
    taskUtils.executeIfNotActive = executeIfNotActive;
})(taskUtils = exports.taskUtils || (exports.taskUtils = {}));
//# sourceMappingURL=taskUtils.js.map