"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.selectWorkspaceItem = exports.selectWorkspaceFile = exports.selectWorkspaceFolder = void 0;
const path = require("path");
const vscode = require("vscode");
const localize_1 = require("../localize");
function selectWorkspaceFolder(context, placeHolder) {
    return __awaiter(this, void 0, void 0, function* () {
        return yield selectWorkspaceItem(context, placeHolder, {
            canSelectFiles: false,
            canSelectFolders: true,
            canSelectMany: false,
            defaultUri: vscode.workspace.workspaceFolders && vscode.workspace.workspaceFolders.length > 0 ? vscode.workspace.workspaceFolders[0].uri : undefined,
            openLabel: localize_1.localize('select', 'Select')
        });
    });
}
exports.selectWorkspaceFolder = selectWorkspaceFolder;
function selectWorkspaceFile(context, placeHolder, fileExtensions) {
    return __awaiter(this, void 0, void 0, function* () {
        const filters = {};
        if (fileExtensions) {
            filters.Artifacts = fileExtensions;
        }
        return yield selectWorkspaceItem(context, placeHolder, {
            canSelectFiles: true,
            canSelectFolders: false,
            canSelectMany: false,
            openLabel: localize_1.localize('select', 'Select'),
            filters: filters
        });
    });
}
exports.selectWorkspaceFile = selectWorkspaceFile;
function selectWorkspaceItem(context, placeHolder, options) {
    return __awaiter(this, void 0, void 0, function* () {
        let folder;
        if (vscode.workspace.workspaceFolders) {
            const folderPicks = yield Promise.all(vscode.workspace.workspaceFolders.map((f) => {
                return { label: path.basename(f.uri.fsPath), description: f.uri.fsPath, data: f };
            }));
            folderPicks.push({ label: localize_1.localize('azFunc.browse', '$(file-directory) Browse...'), description: '', data: undefined });
            folder = (yield context.ui.showQuickPick(folderPicks, { placeHolder })).data;
        }
        if (folder) {
            return folder;
        }
        else {
            context.telemetry.properties.browse = 'true';
            return (yield context.ui.showOpenDialog(options))[0];
        }
    });
}
exports.selectWorkspaceItem = selectWorkspaceItem;
//# sourceMappingURL=workspace.js.map