"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.verifyNoRunFromPackageSetting = void 0;
const extensionVariables_1 = require("./extensionVariables");
const localize_1 = require("./localize");
// prior to git deploying, these settings must be deleted or it will fail
function verifyNoRunFromPackageSetting(context, site) {
    return __awaiter(this, void 0, void 0, function* () {
        let updateSettings = false;
        const runFromPackageSettings = ['WEBSITE_RUN_FROM_PACKAGE', 'WEBSITE_RUN_FROM_ZIP'];
        const client = yield site.createClient(context);
        const applicationSettings = yield client.listApplicationSettings();
        for (const settingName of runFromPackageSettings) {
            if (applicationSettings.properties && applicationSettings.properties[settingName]) {
                delete applicationSettings.properties[settingName];
                extensionVariables_1.ext.outputChannel.appendLog(localize_1.localize('deletingSetting', 'Deleting setting "{0}"...', settingName), { resourceName: site.fullName });
                updateSettings = true;
            }
        }
        if (updateSettings) {
            yield client.updateApplicationSettings(applicationSettings);
        }
    });
}
exports.verifyNoRunFromPackageSetting = verifyNoRunFromPackageSetting;
//# sourceMappingURL=verifyNoRunFromPackageSetting.js.map